const { ContainerSession, Pricing } = window['@refinitiv/dataplatform-containersession'];

const sxs = window.sxsWeb;

// For users, who use a private network
// sxs("config", "use-network", "private");


sxs.start(new Date());
sxs.onLoad(async () => {
    console.log('[DEMO] WebSDK Loaded at time: ' + new Date());

    const dataSession = ContainerSession.Definition({
        appKey: 'InputAppKeyHere',
        bus: sxs
    }).getSession();

    try {
        await dataSession.open();

        const pricingDefinition = Pricing.Definition({
            universe: 'EUR=',
            fields: ['DSPLY_NAME', 'PRCTCK_1', 'TRDPRC_1', 'PCTCHNG', 'HIGH_1', 'LOW_1']
        });

        const stream = await pricingDefinition.getStream(dataSession);

        stream
            .onRefresh((refresh, instrument) => console.log(instrument, refresh))
            .onUpdate((update, instrument) => console.log(instrument, update))
            .onStatus((status, instrument) => console.log(instrument, status))
            .onComplete(() => console.log('Complete'))
            .onError(err => console.log(err));

        await stream.open();

        // The StreamingPrice will be closed after 30 seconds
        await new Promise(res => setTimeout(res, 30000));
        await stream.close();

    } catch (err) {
        console.log(err);
    } finally {
        await dataSession.close();
    }
});
